@@ -1,5 +1,6 @@
 from functools import wraps
 
+from .cloudformation.exceptions import CFError
 from .cognito.exceptions import CognitoError
 from .s3.exceptions import S3Error
 
@@ -30,3 +31,17 @@ def wrap_and_reraise_cognito_errors(func):
             raise CognitoError from e
 
     return wrapper_func
+
+
+def wrap_and_reraise_cloudformation_errors(func):
+
+    @wraps(func)
+    def wrapper_func(*args, **kwargs):
+        try:
+            return func(*args, **kwargs)
+        except CFError:
+            raise   # Pass through CFError Exceptions
+        except Exception as e:
+            raise CFError from e
+
+    return wrapper_func
